

class Api(object):
    """TBD
    """

    def set_state(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_state_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_capability_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_config(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_port_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_capture_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_flow_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_bgpv4_results(self, content):
        """TBD
        """
        raise NotImplementedError
